<?php

	/**
	 * Programme principal
	 * Construit le flux RSS
	 ***/
	
	// Import du fichier de configuration
	require(dirname(__FILE__).'/news-config.inc.php');
	
	// Import de la classe RSSFeed
	require(dirname(__FILE__).'/RSSFeed/RSSFeed.class.php');


	/**
	 * Déclaration des variables globales
	 ***/

	 
	// Objets de connexion et de manipulatin de la BDD
	$oPDO = null;
	$oPDOStatement = null;
	
	// Objets de manipulation du fichier RSS
	$oRssFeed = null;
	$oRssItem = null;
	
	// Tableau stockant les news issues de la bdd
	$aDernieresNews = array();

	// Variable stockant l'email issu de la BDD
	$sEmail = '';

	try
	{

		// Connexion sur la BDD
		$oPDO = new PDO(DB_DSN, DB_LOGIN, DB_PASSWORD);
		$oPDO->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
		
		// Récupération des dernières news valides
		$oPDOStatement = $oPDO->query
		(
			"SELECT 
					actu.id, 
					actu.categorie_id, 
					actu.titre, 
					actu.corps, 
					actu.auteur, 
					actu.email, 
					actu.creation, 
					cat.libelle 
				FROM ". DB_ACTUALITE_TABLE ." AS actu,". DB_CATEGORIE_TABLE ." AS cat 
				WHERE 
						publication=1
					AND 
						actu.categorie_id = cat.id 
				ORDER BY creation DESC LIMIT 0,". MAX_NEWS_PAR_FLUX
		);
		
		
		// Stockage des news dans un tableau
		$aDernieresNews = $oPDOStatement->fetchAll(PDO::FETCH_OBJ);
		
		// Fermeture de la connexion SQL
		$oPDO = null;
		
	}
	catch(PDOException $e)
	{
		echo $e->getMessage();
	}
	
	// A-t-on récupéré des enregistrements ?
	if(sizeof($aDernieresNews)>0)
	{
		// Création des entêtes du flux RSS
		$oRssFeed = new RSSFeed('utf-8');
		$oRssFeed->setProtectString(true);
		$oRssFeed->setTitle('Flux RSS des actualités');
		$oRssFeed->setDescription('Les dernières actualités directement par flux RSS');
		$oRssFeed->setLink(URL_SITE .'/'. basename(__FILE__));
		$oRssFeed->setPubDate('2007-12-31');
		$oRssFeed->setLastBuildDate(date('Y-m-d'));
		$oRssFeed->setWebMaster(WEBMASTER_EMAIL,WEBMASTER_NOM);
		$oRssFeed->setManagingEditor(WEBMASTER_EMAIL,WEBMASTER_NOM);
		$oRssFeed->setCopyright('(C) Copyright 2007 - VotreSite.com - Tous droits réservés - reproduction interdite');
		$oRssFeed->setGenerator('Powered with RSSFeed Class by Hugo "Emacs" HAMON - http://www.apprendre-php.com');
		$oRssFeed->setLanguage('fr');
	
		// Ajout des news au flux
		foreach($aDernieresNews as $oNews)
		{
			// Récupération de l'email
			$sEmail = $oNews->email;
			
			$oRssItem = new RSSFeedItem();
			$oRssItem->setTitle($oNews->titre);
			$oRssItem->setDescription($oNews->corps);
			$oRssItem->setLink(URL_SITE .'/news.php?id='. $oNews->id);
			$oRssItem->setGuid(URL_SITE .'/news.php?id='. $oNews->id, true);
			
			if(!empty($sEmail))
			{
				$oRssItem->setAuthor($sEmail, $oNews->auteur);
			}
			
			$oRssItem->setPubDate($oNews->creation);
			$oRssFeed->appendItem($oRssItem);
			$oRssItem = null;
		}
		
		// Sauvegarde du flux RSS
		$oRssFeed->save('rss-news.xml');
		
		// Affichage sur la sortie standard
		header('Content-Type: text/xml; charset=utf-8');
		$oRssFeed->display();
	}
	
?>